@@ -35,6 +35,11 @@ func AcquireLeases(ctx context.Context, machines []*fly.Machine) ([]*fly.Machine
 	for _, m := range machines {
 		m := m
 		acquirePool.Go(func() (*fly.Machine, error) {
+			// Skip leasing for unreachable machines
+			if m.HostStatus != fly.HostStatusOk {
+				return m, nil
+			}
+
 			m, _, err := AcquireLease(ctx, m)
 			return m, err
 		})
